@@ -1,3 +1,7 @@
+"""
+Output format interfaces and implementations for `pip-audit`.
+"""
+
 from .columns import ColumnsFormat  # noqa: F401
 from .interface import VulnerabilityFormat  # noqa: F401
 from .json import JsonFormat  # noqa: F401
